Documentation
¶
Overview ¶
Package skip provides helper functions for skipping test cases.
Index ¶
- func Architecture(t T, names ...string)
- func CgroupsVersion(t T, version int)
- func CommandUnavailable(t T, command string)
- func DockerUnavailable(t T)
- func EnvironmentVariableMatches(t T, name string, values ...string)
- func EnvironmentVariableNotMatches(t T, name string, values ...string)
- func EnvironmentVariableNotSet(t T, name string)
- func EnvironmentVariableSet(t T, name string)
- func Error(t T, err error)
- func MaximumCores(t T, num int)
- func MinimumCores(t T, num int)
- func NotArchitecture(t T, names ...string)
- func NotOperatingSystem(t T, names ...string)
- func NotUserRoot(t T)
- func OperatingSystem(t T, names ...string)
- func PodmanUnavailable(t T)
- func UserRoot(t T)
- type T
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Architecture ¶
Architecture will skip the test if the Go runtime detects the system architecture matches one of the given names.
func CgroupsVersion ¶
CgroupsVersion will skip the test if the system does not match the given cgroups version.
func CommandUnavailable ¶
CommandUnavailable will skip the test if the given command cannot be found on the system PATH.
func DockerUnavailable ¶
func DockerUnavailable(t T)
DockerUnavailable will skip the test if the docker command cannot be found on the system PATH.
func EnvironmentVariableMatches ¶
EnvironmentVariableMatches will skip the test if the system environment matches one of the given environment variable values.
func EnvironmentVariableNotMatches ¶
EnvironmentVariableNotMatches will skip the test if the system environment does not match one of the given environment variable values.
func EnvironmentVariableNotSet ¶
EnvironmentVariableNotSet will skip the test if the given environment variable is not set in the system environment.
func EnvironmentVariableSet ¶
EnvironmentVariableSet will skip the test if the given environment variable is set to any value.
func MaximumCores ¶
MaximumCores will skip the test if the number of cores on the system exceeds the given maximum.
func MinimumCores ¶
MinimumCores will skip the test if the system does not meet the minimum number of CPU cores.
func NotArchitecture ¶
NotArchitecture will skip the test if the Go runtime the system architecture does not match one of the given names.
func NotOperatingSystem ¶
NotOperatingSystem will skip the test if the Go runtime detects the operating system does not match one of the given names.
func NotUserRoot ¶
func NotUserRoot(t T)
NotUserRoot will skip the test if the test is not being run as the root user.
Uses the effective UID value to determine user.
func OperatingSystem ¶
OperatingSystem will skip the test if the Go runtime detects the operating system matches one of the given names.
func PodmanUnavailable ¶
func PodmanUnavailable(t T)
PodmanUnavailable will skip the test if the podman command cannot be found on the system PATH.